%feature("docstring") OT::LinearModelStepwiseAlgorithm
"Stepwise linear model algorithm.

**Available usages**:

    LinearModelStepwiseAlgorithm(*inputSample, basis, outputSample, minimalIndices, isForward, penalty, maximumIterationNumber*)

    LinearModelStepwiseAlgorithm(*inputSample, basis, outputSample, minimalIndices, startIndices, penalty, maximumIterationNumber*)

Parameters
----------
inputSample, outputSample : 2-d sequence of float
    The input and output samples of a model.
basis : :class:`~openturns.Basis`
    Functional basis to estimate the trend.
minimalIndices : sequence of int
    The indices of minimal model
isForward : bool
      the boolean value used for the stepwise regression method direction FORWARD and BACKWARD.
startIndices : sequence of int
     The indices of start model used for the stepwise regression method direction BOTH.
penalty : float
     The multiple of the degrees of freedom used for the penalty of the stepwise regression method:

     - 2      Akaike   information criterion (AIC)
     - log(n) Bayesian information criterion (BIC)
maximumIterationNumber : int
     The maximum number of iterations of the stepwise regression method.


See Also
--------
LinearModelAlgorithm, LinearModelResult

Notes
-----
The objective is to select the best linear regression model by using the 
stepwise method. Starting from the `basis` and `minimalIndices`, the stepwise 
strategy consists in adding basis elements (if `isForward` is True), dropping 
some (if `isForward` is False) or adding and dropping (`both` strategy) some 
elements. At each step, we get a model. We compute the corresponding penalty 
(BIC or AIC) and we continue repeatedly this process until the penalty could 
not be improved or the maximum iterations number is reached.
Finally we get a regression model between the scalar variable :math:`Y`
and the :math:`n`-dimensional one :math:`\\vect{X} = (X_i)_{i \\leq n}` writes as follows:

.. math::

    \\tilde{Y} = a_0 + \\sum_{i \\in I} a_i \\phi_i(X) + \\epsilon

where :math:`\\epsilon` is the residual, supposed to follow the standard Normal
distribution, :math:`\\phi_i` the i-th element of the basis.
"

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModelStepwiseAlgorithm::getDirection
"Accessor to the direction.

Returns
-------
direction : int
    Direction."

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModelStepwiseAlgorithm::getFormula
"Accessor to the formula.

Returns
-------
formula : str
    Formula."

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModelStepwiseAlgorithm::getInputSample
"Accessor to the input sample.

Returns
-------
input_sample : :class:`~openturns.Sample`
    Input sample."

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModelStepwiseAlgorithm::getMaximumIterationNumber
"Accessor to the maximum iteration number.

Returns
-------
maximum_iteration : int
    Maximum number of iterations."

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModelStepwiseAlgorithm::getOutputSample
"Accessor to the output sample.

Returns
-------
output_sample : :class:`~openturns.Sample`
    Output sample."

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModelStepwiseAlgorithm::getPenalty
"Accessor to the penalty.

Returns
-------
penalty : float
    Penalty."

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModelStepwiseAlgorithm::getResult
"Accessor to the result.

Returns
-------
result : :class:`~openturns.LinearModelResult`
    The result."

// ---------------------------------------------------------------------

%feature("docstring") OT::LinearModelStepwiseAlgorithm::run
"Run the algorithm."
